@@ -77,10 +77,10 @@ MainWidget::MainWidget(TQWidget* parent, const char* name, WFlags fl): MainWidge
   m_currentState=m_state.begin();
   m_currentPreview=m_oldPreviews.begin();
 
-  connect(&tracer,TQT_SIGNAL(processExited()),this,TQT_SLOT(tracerExited()));
-  connect(&tracer,TQT_SIGNAL(wroteToStdin()),this,TQT_SLOT(writeCompleted()));
-  connect(traceBtn,TQT_SIGNAL(clicked()),this,TQT_SLOT(trace()));
-  connect(defaultBtn,TQT_SIGNAL(clicked()),this,TQT_SLOT(defaultOptions()));
+  connect(&tracer,TQ_SIGNAL(processExited()),this,TQ_SLOT(tracerExited()));
+  connect(&tracer,TQ_SIGNAL(wroteToStdin()),this,TQ_SLOT(writeCompleted()));
+  connect(traceBtn,TQ_SIGNAL(clicked()),this,TQ_SLOT(trace()));
+  connect(defaultBtn,TQ_SIGNAL(clicked()),this,TQ_SLOT(defaultOptions()));
 
   emit(signalChangeStatusbar(i18n("Checking autotrace formats.")));
   AutotraceFormats *formats=new AutotraceFormats();
