@@ -55,7 +55,7 @@ potracegui::potracegui()
 	setAutoSaveSettings();
 	setAcceptDrops(true);
 
-	connect(m_centralWidget,TQT_SIGNAL(signalChangeStatusbar(TQString)),this,TQT_SLOT(changeStatusbar(TQString)));
+	connect(m_centralWidget,TQ_SIGNAL(signalChangeStatusbar(TQString)),this,TQ_SLOT(changeStatusbar(TQString)));
 	 
 	createInterface();
 }
@@ -67,21 +67,21 @@ potracegui::~potracegui()
 void potracegui::createInterface()
 {
 	 /*handled by potracegui*/
-	 KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(fileNew()),actionCollection());
-	 KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(quit()),actionCollection());
-	 m_toolbarAction=KStdAction::showToolbar(TQT_TQOBJECT(this), TQT_SLOT(showToolbar()),actionCollection());
-	 m_statusbarAction=KStdAction::showStatusbar(TQT_TQOBJECT(this), TQT_SLOT(showStatusbar()),actionCollection());
-	 KStdAction::keyBindings(TQT_TQOBJECT(this), TQT_SLOT(configureKeys()),actionCollection());
-	 KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(configureTB()),actionCollection());
+	 KStdAction::openNew(this, TQ_SLOT(fileNew()),actionCollection());
+	 KStdAction::quit(this, TQ_SLOT(quit()),actionCollection());
+	 m_toolbarAction=KStdAction::showToolbar(this, TQ_SLOT(showToolbar()),actionCollection());
+	 m_statusbarAction=KStdAction::showStatusbar(this, TQ_SLOT(showStatusbar()),actionCollection());
+	 KStdAction::keyBindings(this, TQ_SLOT(configureKeys()),actionCollection());
+	 KStdAction::configureToolbars(this, TQ_SLOT(configureTB()),actionCollection());
 	 
 	 /*handled by MainWidget*/
-	 KStdAction::open(TQT_TQOBJECT(m_centralWidget), TQT_SLOT(fileOpen()),actionCollection());
-	 KStdAction::save(TQT_TQOBJECT(m_centralWidget), TQT_SLOT(fileSave()),actionCollection());
-	 KStdAction::saveAs(TQT_TQOBJECT(m_centralWidget), TQT_SLOT(fileSaveAs()),actionCollection());
-	 KStdAction::close(TQT_TQOBJECT(m_centralWidget), TQT_SLOT(fileClose()),actionCollection());
-	 KStdAction::cut(TQT_TQOBJECT(m_centralWidget), TQT_SLOT(cut()),actionCollection());
-	 KStdAction::copy(TQT_TQOBJECT(m_centralWidget), TQT_SLOT(copy()),actionCollection());
-	 KStdAction::paste(TQT_TQOBJECT(m_centralWidget), TQT_SLOT(paste()),actionCollection());
+	 KStdAction::open(m_centralWidget, TQ_SLOT(fileOpen()),actionCollection());
+	 KStdAction::save(m_centralWidget, TQ_SLOT(fileSave()),actionCollection());
+	 KStdAction::saveAs(m_centralWidget, TQ_SLOT(fileSaveAs()),actionCollection());
+	 KStdAction::close(m_centralWidget, TQ_SLOT(fileClose()),actionCollection());
+	 KStdAction::cut(m_centralWidget, TQ_SLOT(cut()),actionCollection());
+	 KStdAction::copy(m_centralWidget, TQ_SLOT(copy()),actionCollection());
+	 KStdAction::paste(m_centralWidget, TQ_SLOT(paste()),actionCollection());
 	 
 	 /*Create menu and toolbar*/
 	 createGUI();
@@ -123,7 +123,7 @@ void potracegui::configureKeys()
 void potracegui::configureTB()
 {
 	KEditToolbar dlg(actionCollection());
-	connect(&dlg,TQT_SIGNAL(newToolbarConfig()),this,TQT_SLOT(NewTBConfig()));
+	connect(&dlg,TQ_SIGNAL(newToolbarConfig()),this,TQ_SLOT(NewTBConfig()));
 	dlg.exec();
 }
 
